@@ -2,7 +2,12 @@ getVCOV <- function(model){
   if (!is.null(model@information)){
     Info <- model@information
   } else {
-    Info <- psychonetrics_FisherInformation(model)
+    if (model@cpp){
+      Info <- psychonetrics_FisherInformation_cpp(model)
+    } else {
+      Info <- psychonetrics_FisherInformation(model)      
+    }
+
   }
   
   1/sum(model@sample@groups$nobs) * as.matrix(solve_symmetric(Info))
